@@ -6,10 +6,8 @@ use Carp();
 
 use Rose::HTML::Form::Field::Text;
 
-use Rose::HTML::Form::Field::Compound;
-use Rose::HTML::Form::Field::PhoneNumber::US;
-our @ISA = qw(Rose::HTML::Form::Field::Compound
-              Rose::HTML::Form::Field::PhoneNumber::US);
+use base qw(Rose::HTML::Form::Field::Compound
+            Rose::HTML::Form::Field::PhoneNumber::US);
 
 # Multiple inheritence never quite works out the way I want it to...
 Rose::HTML::Form::Field::PhoneNumber::US->import_methods
@@ -24,7 +22,7 @@ Rose::HTML::Form::Field::Compound->import_methods
   'name',
 );
 
-our $VERSION = '0.50';
+our $VERSION = '0.606';
 
 sub build_field
 {
@@ -176,4 +174,4 @@ John C. Siracusa (siracusa@gmail.com)
 
 =head1 LICENSE
 
-Copyright (c) 2009 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2010 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
