@@ -4,10 +4,9 @@ use strict;
 
 use Rose::HTML::Object::Errors qw(:time);
 
-use Rose::HTML::Form::Field::Text;
-our @ISA = qw(Rose::HTML::Form::Field::Text);
+use base 'Rose::HTML::Form::Field::Text';
 
-our $VERSION = '0.549';
+our $VERSION = '0.606';
 
 __PACKAGE__->add_required_html_attr(
 {
@@ -88,6 +87,8 @@ if(__PACKAGE__->localizer->auto_load_messages)
   __PACKAGE__->localizer->load_all_messages;
 }
 
+use utf8; # The __DATA__ section contains UTF-8 text
+
 1;
 
 __DATA__
@@ -189,4 +190,4 @@ John C. Siracusa (siracusa@gmail.com)
 
 =head1 LICENSE
 
-Copyright (c) 2009 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2010 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
