@@ -2,10 +2,9 @@ package Rose::HTML::Link;
 
 use strict;
 
-use Rose::HTML::Object;
-our @ISA = qw(Rose::HTML::Object);
+use base 'Rose::HTML::Object';
 
-our $VERSION = '0.53';
+our $VERSION = '0.606';
 
 __PACKAGE__->add_valid_html_attrs
 (
@@ -88,4 +87,4 @@ John C. Siracusa (siracusa@gmail.com)
 
 =head1 LICENSE
 
-Copyright (c) 2009 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2010 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
